pub fn batch_prove_and_write_evals<F, Prover>(
provers: Vec<Prover>,
channel: &mut impl IPProverChannel<F>,
) -> BatchSumcheckOutput<F>where
F: Field,
Prover: SumcheckProver<F>,Expand description
Prove a batched sumcheck protocol and write evaluation claims to the channel.
This function combines batch_prove with writing the evaluation claims to the channel.
It performs the batched sumcheck protocol execution and then writes all the multilinear
evaluation values to the channel in order.
Arguments
provers- Vector of sumcheck provers, each handling one claim in the batchchannel- The channel for sending prover messages and sampling challenges
Returns
Returns BatchSumcheckOutput containing the challenges and evaluation claims that were
written to the channel.